# Deployment (Nginx)

INJECT in additional to basal deployment of Frontend and Backend containers, it's also to possible to utilize a simplified deployment method via Docker Compose. This method simplifies the deployment by creating necessary settings, pairings between Frontend and Backend and also creates a singular endpoint for accessing INJECT.

This solution consists of 3+1 containers: Frontend, Backend, Nginx Proxy (as a front-facing router) and CertBot.

Frontend and Backend in this configuration are setup to communicate under a single endpoint, this is then handled by Nginx Proxy which forwards appropriate requests either to Frontend (for fetching static app data) or Backend (for interacting the proxy). Certbot handles generation of HTTPS certificates and it's only included for usage if it's assumed to host via HTTPS.

Certbot in the current state only simplifies creation of new certificates but it's not automated.

# Environment variables

For environment variables please refer to `.env`. The example file in the repository contains ideal set of environment variables allowing user to setup the platform. 

```env
# sets up appropriate hostname for the Nginx server
EXTERNAL_HOST=inject.localhost

# disable AAI, uncomment the next two lines to enable it
INJECT_NOAUTH=true
VITE_NOAUTH=$INJECT_NOAUTH

# host parametres that should be setup for client and server to interact correctly
INJECT_HOST_ADDRESSES=$EXTERNAL_HOST
VITE_HTTP_HOST=$EXTERNAL_HOST
VITE_HTTP_WS=ws://$EXTERNAL_HOST/ttxbackend/api/v1/subscription
CORS_ALLOWED_ORIGINS=http://$EXTERNAL_HOST

# for certbot generation, use with certbot-generator.yml
CERTBOT_EMAIL=noemail@inject.localhost

# for email sending of AAI mails
INJECT_EMAIL_HOST=
INJECT_EMAIL_PORT=
INJECT_EMAIL_HOST_USER=
INJECT_EMAIL_HOST_PASSWORD=
INJECT_EMAIL_SENDER_ADDRESS=

# enable logging to a specific file
# INJECT_LOGS=

# enable debug mode for the backend
INJECT_DEBUG=

# nginx settings, do not touch unless you know what you are doing
NGINX_DEFAULT_REQUEST=index.html
NGINX_ROOT=dist
```

Special care needs to be given to host parameters block, which establishes the link between the clients (users of the frontend application) and the server (backend). In case it's necessary to setup HTTPS it's needed to ensure that the connection strings set the protocol appopriately (`http` vs `https`, `ws` vs `wss`). The most important config of all is `EXTERNAL_HOST` which commands under which domain the INJECT platform will run on. 

# HTTP Deployment

For HTTP deployment please refer to `deploy.sh` script in the folder, this script launches three Docker compose layers which form a complete script. The first one is the basal binding compose file (`docker-compose.yml`), which establishes the basic bindings between Frontend, Backend and Nginx Proxy. The second one (`compose-from-registry.yml`) sets up appopriate import paths for Frontend and Backend images, this can be interchangibly swapped for `compose-from-monorepo.yml` for development purposes. The last one (`compose-with-nginx.yml`) sets up Nginx Proxy to run in HTTP mode under port `80` and generates necessary nginx configuration from `nginx.conf.template`.

# HTTPS Deployment

In comparision to HTTP Deployment, HTTPS differs majorly in one way which is requirement to have HTTPS certificates generated. These certificates can be generated via `generate-cert.sh` script which will output certificates in the `./certbot` directory of the compose script for given `EXTERNAL_HOST` setup in `.env` file.

It's necessary to ensure that `VITE_HTTP_HOST`, `VITE_HTTP_WS`, `CORS_ALLOWED_ORIGINS` have correctly setup prepending protocols, i.e. `https` and `wss`. If not, it will cause connection errors.

When the certificates are generated, the only step needed to take is to execute `deploy-with-https.sh` which will run INJECT in HTTPS mode. The script is similar to `deploy.sh` with one caveat and that's usage of `compose-with-nginx-https.yml` instead of `compose-with-nginx.yml` which by essence does the same but uses different NGINX template (`nginx-https.conf.template`) and runs on ports `80`, `443`.

# Disabling AAI

To disable AAI please refer to `.env` file and patch env variables `INJECT_NOAUTH` and `VITE_NOAUTH`.
